"use strict";
/*
Copyright 2022-2024 New Vector Ltd.

SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only
Please see LICENSE files in the repository root for full details.
*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Settings = void 0;
const tray = __importStar(require("./tray"));
exports.Settings = {
    "Electron.autoLaunch": {
        async read() {
            return global.launcher.isEnabled();
        },
        async write(value) {
            if (value) {
                return global.launcher.enable();
            }
            else {
                return global.launcher.disable();
            }
        },
    },
    "Electron.warnBeforeExit": {
        async read() {
            return global.store.get("warnBeforeExit", true);
        },
        async write(value) {
            global.store.set("warnBeforeExit", value);
        },
    },
    "Electron.alwaysShowMenuBar": {
        // not supported on macOS
        async read() {
            return !global.mainWindow.autoHideMenuBar;
        },
        async write(value) {
            global.store.set("autoHideMenuBar", !value);
            global.mainWindow.autoHideMenuBar = !value;
            global.mainWindow.setMenuBarVisibility(value);
        },
    },
    "Electron.showTrayIcon": {
        // not supported on macOS
        async read() {
            return tray.hasTray();
        },
        async write(value) {
            if (value) {
                // Create trayIcon icon
                tray.create(global.trayConfig);
            }
            else {
                tray.destroy();
            }
            global.store.set("minimizeToTray", value);
        },
    },
    "Electron.enableHardwareAcceleration": {
        async read() {
            return !global.store.get("disableHardwareAcceleration", false);
        },
        async write(value) {
            global.store.set("disableHardwareAcceleration", !value);
        },
    },
    "Electron.monochromeIcon": {
        async read() {
            return tray.isMonochrome();
        },
        async write(value) {
            global.store.set("monochromeIcon", value);
            tray.refreshIcon();
        },
    },
};
