"use strict";
/*
Copyright 2022-2024 New Vector Ltd.

SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only
Please see LICENSE files in the repository root for full details.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.randomArray = randomArray;
exports.loadJsonFile = loadJsonFile;
const crypto_1 = __importDefault(require("crypto"));
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
async function randomArray(size) {
    return new Promise((resolve, reject) => {
        crypto_1.default.randomBytes(size, (err, buf) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(buf.toString("base64").replace(/=+$/g, ""));
            }
        });
    });
}
/**
 * Synchronously load a JSON file from the local filesystem.
 * Unlike `require`, will never execute any javascript in a loaded file.
 * @param paths - An array of path segments which will be joined using the system's path delimiter.
 */
function loadJsonFile(...paths) {
    const file = node_fs_1.default.readFileSync(node_path_1.default.join(...paths), { encoding: "utf-8" });
    return JSON.parse(file);
}
